@@ -2,11 +2,14 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute
+//
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -30,6 +33,7 @@ struct CallbackList
 
 static CallbackList *s_motionList = NULL;
 static CallbackList *s_buttonList = NULL;
+static CallbackList *s_wheelList = NULL;
 static CallbackList *s_tabmotionList = NULL;
 static CallbackList *s_tabrotationList = NULL;
 static CallbackList *s_tabbuttonList = NULL;
@@ -90,6 +94,7 @@ GEM_EXTERN void removeMotionCallback(MOTION_CB callback, void *data)
 GEM_EXTERN void setButtonCallback(BUTTON_CB callback, void *data)
 {
     CallbackList *newCallback = new CallbackList;
+
     newCallback->data = data;
     newCallback->func = (void *)callback;
 
@@ -131,6 +136,53 @@ GEM_EXTERN void removeButtonCallback(BUTTON_CB callback, void *data)
     }
 }
 /////////////////////////////////////////////////////////
+// Wheel callbacks
+//
+/////////////////////////////////////////////////////////
+GEM_EXTERN void setWheelCallback(WHEEL_CB callback, void *data)
+{
+    CallbackList *newCallback = new CallbackList;
+    newCallback->data = data;
+    newCallback->func = (void *)callback;
+
+    if (!s_wheelList)
+        s_wheelList = newCallback;
+    else
+    {
+        CallbackList *theList = s_wheelList;
+        while(theList->next)
+            theList = theList->next;
+        theList->next = newCallback;
+    }
+}
+GEM_EXTERN void removeWheelCallback(WHEEL_CB callback, void *data)
+{
+    CallbackList *theList = s_wheelList;
+    if (!theList)
+        return;
+    else if (theList->func == (void *)callback &&
+             theList->data == data)
+    {
+        s_wheelList = theList->next;
+        delete theList;
+    }
+    else
+    {
+        while(theList->next)
+        {
+            if (theList->next->func == (void *)callback &&
+                theList->next->data == data)
+            {
+                CallbackList *holder = theList->next;
+                theList->next = holder->next;
+                delete holder;
+                return;
+            }
+            theList = theList->next;
+        }
+    }
+}
+/////////////////////////////////////////////////////////
 // Tablet motion callbacks
 //
 /////////////////////////////////////////////////////////
@@ -390,6 +442,16 @@ GEM_EXTERN void triggerButtonEvent(int which, int state, int x, int y)
         theList = theList->next;
     }
 }
+GEM_EXTERN void triggerWheelEvent(int axis, int value)
+{
+    CallbackList *theList = s_wheelList;
+    while(theList)
+    {
+        WHEEL_CB callback = (WHEEL_CB)theList->func;
+        (*callback)(axis, value, theList->data);
+        theList = theList->next;
+    }
+}
 GEM_EXTERN void triggerTabletMotionEvent(int x, int y, float pressure)
 {
     CallbackList *theList = s_tabmotionList;
@@ -420,13 +482,13 @@ GEM_EXTERN void triggerTabletButtonEvent(int which, int state, int x, int y)
         theList = theList->next;
     }
 }
-GEM_EXTERN void triggerKeyboardEvent(char value, int state)
+GEM_EXTERN void triggerKeyboardEvent(char *string, int value, int state)
 {
     CallbackList *theList = s_keyboardList;
     while(theList)
     {
         KEYBOARD_CB callback = (KEYBOARD_CB)theList->func;
-        (*callback)(value, state, theList->data);
+        (*callback)(string, value, state, theList->data);
         theList = theList->next;
     }
 }
