@@ -2,11 +2,15 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute
+//    Copyright (c) 2002-2003 james tittle/tigital
+//
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,63 +20,173 @@
 
 #include "m_pd.h"
 
-#ifndef unix
+#ifdef __APPLE__
+#include <Carbon/carbon.h>
+#include <QuickTime/QuickTime.h>
+#include <OpenGL/gl.h>
+#include <OpenGL/glext.h>
+#include <string.h>
+#endif // __APPLE__
+
+#ifdef _WINDOWS
 #include <io.h>
 #else
 #include <unistd.h>
-#define _close close
 #endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <setjmp.h>
 
+#include <string.h>
+
+#ifndef __APPLE__
 extern "C"
 {
-    #include "tiffio.h"
+#include "tiffio.h"
+
+#undef EXTERN
+
 #ifdef _WINDOWS
-	#undef EXTERN
-	#undef FAR
+#undef FAR
 #endif
-	#include "jpeglib.h"
+
+#include "jpeglib.h"
 }
 
 
 #include "sgiimage.h"
+#endif // __APPLE__
+
 #include "GemPixUtil.h"
 
+#ifdef __APPLE__
+imageStruct *QTImage2mem(GraphicsImportComponent inImporter);
+OSStatus FSPathMakeFSSpec(
+	const UInt8 *path,
+	FSSpec *spec,
+	Boolean *isDirectory);
+#else
 imageStruct *tiffImage2mem(const char *filename);
 imageStruct *jpegImage2mem(const char *filename);
 imageStruct *sgiImage2mem(const char *filename);
 
+
+/* this function gives us 32 byte aligned data, the cache line size
+   of  pentiums */
+
+unsigned char* img_allocate(int size)
+{
+  unsigned char* data;
+#if 0
+  unsigned char* pad;
+  pad = new unsigned char[size];
+  data = (unsigned char*) ((((unsigned int)pad)+31)& (~31));
+#else
+  data = new unsigned char [size];
+#endif
+
+  return data; 
+}
+#endif // __APPLE__
+
 /***************************************************************************
  *
  * image2mem - Read in an image in various file formats
  *
  ***************************************************************************/
+#ifdef __APPLE__
 GEM_EXTERN imageStruct *image2mem(const char *filename)
 {
+	OSErr				err;
+	imageStruct 			*image_block = NULL;
+	GraphicsImportComponent 	importer = NULL;
+
 	// does the file even exist?
-	char realName[256];
-	char *realResult;
-	int fd = open_via_path(".", filename, "", realName, &realResult, 256);
-	if (!fd)
+	if (filename[0] != '\0') {
+		FSSpec	spec;
+
+		err = ::FSPathMakeFSSpec( (UInt8*)filename, &spec, NULL);
+		if (err) {
+			error("GEM: Unable to find file: %#s", spec.name);
+                        error("GEM: Unable to find filename:%s", filename);
+			error("parID : %d", spec.parID); 
+			return NULL;
+		}
+		err = ::GetGraphicsImporterForFile(&spec, &importer);
+		if (err) {
+			error("GEM: Unable to import an image: %#s", spec.name);
+			return NULL;
+		}
+	}
+	image_block = QTImage2mem(importer);
+	::CloseComponent(importer);
+	if (image_block)	return image_block;
+	else			return NULL;
+}
+/*****************************************************************************/
+
+OSStatus
+FSPathMakeFSSpec(
+	const UInt8 *path,
+	FSSpec *spec,
+	Boolean *isDirectory)	/* can be NULL */
+{
+	OSStatus	result;
+	FSRef		ref;
+	
+	/* check parameters */
+	require_action(NULL != spec, BadParameter, result = paramErr);
+	
+	/* convert the POSIX path to an FSRef */
+	result = FSPathMakeRef(path, &ref, isDirectory);
+	require_noerr(result, FSPathMakeRef);
+	
+	/* and then convert the FSRef to an FSSpec */
+	result = FSGetCatalogInfo(&ref, kFSCatInfoNone, NULL, NULL, spec, NULL);
+	require_noerr(result, FSGetCatalogInfo);
+	
+FSGetCatalogInfo:
+FSPathMakeRef:
+BadParameter:
+
+	return ( result );
+}
+
+#else
+GEM_EXTERN imageStruct *image2mem(const char *filename)
+{
+	imageStruct *image_block = NULL;
+	char newName[256];
+
+	// does the file even exist?
+	if (filename[0] == '/' || filename[0] == '\\')
 	{
-		error("GEM: Unable to find file: %s", filename);
-		return(NULL);
+		strcpy(newName, filename);
 	}
 	else
 	{
-		_close(fd);
+		char realName[256];
+		char *realResult;
+
+		int fd = open_via_path(".", filename, "", realName, &realResult, 256, 0);
+		if (fd < 0)
+		{
+			error("GEM: Unable to find file: %s", filename);
+			return(NULL);
+		}
+		else
+		{
+			int res = close(fd);
+			if (res == -1)
+			{
+				int foo;
+				foo = 1;
+			}
+		}
+
+		sprintf(newName, "%s/%s", realName, realResult);
 	}
 
-	imageStruct *image_block = NULL;
-
-	char newName[256];
-	sprintf(newName, "%s/%s", realName, realResult);
-
-	// try to load in a TIFF file
-	if ( (image_block = tiffImage2mem(newName)) )
-			return(image_block);
 	
 	// try to load in a JPEG file
 	if ( (image_block = jpegImage2mem(newName)) )
@@ -82,11 +196,76 @@ GEM_EXTERN imageStruct *image2mem(const char *filename)
 	if ( (image_block = sgiImage2mem(newName)) )
 			return(image_block);
 
+	// try to load in a TIFF file
+	if ( (image_block = tiffImage2mem(newName)) )
+			return(image_block);
+
 	// unable to load image
 	error("GEM: Unable to load image: %s", newName);
 	return(NULL);
 }
+#endif // __APPLE__
+/***************************************************************************
+ *
+ * Read in a image utilizing QuickTime GraphicsImporterComponent
+ *
+ ***************************************************************************/
+#ifdef __APPLE__
+imageStruct *QTImage2mem(GraphicsImportComponent inImporter)
+{
+	Rect		r;
+	if (::GraphicsImportGetNaturalBounds(inImporter, &r)) return NULL;	//get an image size
+	::OffsetRect(&r, -r.left, -r.top);									
+	if (::GraphicsImportSetBoundsRect(inImporter, &r)) return NULL;		
+	ImageDescriptionHandle imageDescH = NULL;
+	if (::GraphicsImportGetImageDescription(inImporter, &imageDescH)) return NULL;
+		
+	imageStruct *image_block = new imageStruct;
+	image_block->xsize	= (*imageDescH)->width;
+	image_block->ysize	= (*imageDescH)->height;
+	//image_block->type	= GL_UNSIGNED_BYTE;
+        image_block->type	= GL_UNSIGNED_INT_8_8_8_8_REV;
+        //image_block->type	= GL_UNSIGNED_INT_8_8_8_8;
+	if ((*imageDescH)->depth <= 32) {
+		image_block->csize = 4;
+		//image_block->format = GL_RGBA;
+                image_block->format = GL_BGRA_EXT;
+	} else {
+		image_block->csize = 1;
+		image_block->format = GL_LUMINANCE;
+	}
+	::DisposeHandle((Handle)imageDescH);
+	imageDescH = NULL;
+	const int dataSize = image_block->ysize * image_block->xsize * image_block->csize;
 
+	image_block->data = new unsigned char[dataSize];
+#ifdef __DEBUG__
+	post("QTImage2mem() : allocate %d bytes", dataSize);
+#endif
+        GWorldPtr	gw = NULL;
+
+	OSErr err = QTNewGWorldFromPtr(&gw, 
+                                    k32ARGBPixelFormat,
+                                    &r, NULL, NULL, 0,
+                                   // keepLocal,	
+                                    //useDistantHdwrMem, 
+                                    image_block->data, 
+                                    (long)(image_block->xsize * image_block->csize));
+	if (image_block->data == NULL || err) {
+		error("Can't allocate memory for an image.");
+	}
+	//image_block->pixelFormat = k32RGBAPixelFormat;
+        //image_block->pixelFormat = k32ARGBPixelFormat;
+	//image_block->pixMapH = GetGWorldPixMap(image_block->gw);
+	//::LockPixels(image_block->pixMapH);
+	::GraphicsImportSetGWorld(inImporter, gw, NULL);
+	::GraphicsImportDraw(inImporter);
+        ::DisposeGWorld(gw);			//dispose the offscreen
+	gw = NULL;
+
+	return image_block;
+}
+#else
 /***************************************************************************
  *
  * Read in a TIFF image.
@@ -150,7 +329,7 @@ imageStruct *tiffImage2mem(const char *filename)
 			return(NULL);
 		}
     
-		image_block->data = new unsigned char[npixels * image_block->csize];
+		image_block->allocate(npixels * image_block->csize);
 		unsigned char *dstLine = &(image_block->data[npixels * image_block->csize]);
         int yStride = image_block->xsize * image_block->csize;
         dstLine -= yStride;
@@ -236,7 +415,7 @@ imageStruct *tiffImage2mem(const char *filename)
 
 		image_block->csize = 4;
 		image_block->format = GL_RGBA;
-		image_block->data = new unsigned char[npixels * image_block->csize];
+		image_block->allocate(npixels * image_block->csize);
 		unsigned char *dstLine = &(image_block->data[npixels * image_block->csize]);
         int yStride = image_block->xsize * image_block->csize;
         dstLine -= yStride;
@@ -372,7 +551,7 @@ imageStruct *jpegImage2mem(const char *filename)
 	int cSize = image_block->csize;
 	image_block->xsize = xSize;
 	image_block->ysize = ySize;
-	image_block->data = new unsigned char[xSize * ySize * cSize];
+	image_block->allocate(xSize * ySize * cSize);
 	
 	// cycle through the scan lines
 	unsigned char *srcLine = new unsigned char[xSize * cSize];
@@ -438,7 +617,7 @@ imageStruct *jpegImage2mem(const char *filename)
  ***************************************************************************/
 imageStruct *sgiImage2mem(const char *filename)
 {
-	long xsize, ysize, csize;
+	int32 xsize, ysize, csize;
 
 	if (!sizeofimage((char *)filename, &xsize, &ysize, &csize) )
 		return(NULL);
@@ -465,7 +644,7 @@ imageStruct *sgiImage2mem(const char *filename)
 		return(NULL);
 	}
 	
-	unsigned long *readData = longimagedata((char *)filename);
+	unsigned int32 *readData = longimagedata((char *)filename);
 	if (!readData)
 	{
 		error("GEM: error reading SGI image file: %s", filename);
@@ -474,7 +653,7 @@ imageStruct *sgiImage2mem(const char *filename)
 	}
 
 	const int dataSize = image_block->ysize * image_block->xsize * image_block->csize;
-	image_block->data = new unsigned char[dataSize];
+	image_block->allocate(dataSize);
 	unsigned char *src = (unsigned char *)readData;
 	unsigned char *dst = &(image_block->data[0]);
     const int yStride = image_block->xsize * image_block->csize;
@@ -538,4 +717,5 @@ imageStruct *sgiImage2mem(const char *filename)
 	
 	return(image_block);
 }
+#endif //__APPLE__
 
