@@ -5,6 +5,8 @@ LOG
     Base class for shapes
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -39,6 +41,7 @@ class GEM_EXTERN GemShape : public GemBase
         // Constructor
         // [in] size - A size of 0. means to just use the default (ie, 1.)
     	GemShape(t_floatarg size);
+	GemShape();
     	
     protected:
     	
@@ -60,8 +63,14 @@ class GEM_EXTERN GemShape : public GemBase
 
     	//////////
     	// How the object should be drawn
-    	virtual void	typeMess(t_symbol *type) = 0;
+    	virtual void	typeMess(t_symbol *type);
     	
+	    //-----------------------------------
+	    // GROUP:	Utility functions
+	    //-----------------------------------
+	
+		void SetVertix(GemState* state,float x, float y, float z, float tx, float ty,int curCoord);
+
 	    //-----------------------------------
 	    // GROUP:	Member variables
 	    //-----------------------------------
@@ -82,14 +91,14 @@ class GEM_EXTERN GemShape : public GemBase
         // The size inlet
         t_inlet         *m_inlet;
 
-	    //-----------------------------------
-	    // GROUP:	Setup functions
-	    //-----------------------------------
+	//-----------------------------------
+	// GROUP:	Setup functions
+	//-----------------------------------
     
     	//////////
     	// creation callback
     	static void 	real_obj_setupCallback(t_class *classPtr)
-    	    { GemBase::real_obj_setupCallback(classPtr); GemShape::obj_setupCallback(classPtr); }
+	  { GemBase::real_obj_setupCallback(classPtr); GemShape::obj_setupCallback(classPtr); }
     	
     private:
     
