@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -15,8 +17,9 @@
 #include "gemmouse.h"
 
 #include "Base/GemEvent.h"
+#include "Base/GemMan.h"
 
-CPPEXTERN_NEW(gemmouse)
+CPPEXTERN_NEW_WITH_GIMME(gemmouse)
 
 /////////////////////////////////////////////////////////
 //
@@ -26,7 +29,7 @@ CPPEXTERN_NEW(gemmouse)
 // Constructor
 //
 /////////////////////////////////////////////////////////
-gemmouse :: gemmouse()
+gemmouse :: gemmouse(int argc, t_atom*argv)
 {
     m_outXPos = outlet_new(this->x_obj, 0);
     m_outYPos = outlet_new(this->x_obj, 0);
@@ -34,9 +37,25 @@ gemmouse :: gemmouse()
     m_outMBut = outlet_new(this->x_obj, 0);
     m_outRBut = outlet_new(this->x_obj, 0);
 
+    m_doY=true;
+
+    switch(argc){
+    case 0:
+      m_scaleX = m_scaleY = 0.f;
+      break;
+    case 1:
+      m_scaleX = m_scaleY = atom_getfloat(argv);
+      m_doY =false;
+      break;
+    default:
+      m_scaleX=atom_getfloat(argv);
+      m_scaleY=atom_getfloat(argv+1);
+    }
+
     // register event callback
     setMotionCallback(&gemmouse::mouseMotionCallback, this);
     setButtonCallback(&gemmouse::mouseButtonCallback, this);
+    setWheelCallback(&gemmouse::mouseWheelCallback, this);
 }
 
 /////////////////////////////////////////////////////////
@@ -48,6 +67,7 @@ gemmouse :: ~gemmouse()
     // remove event callback
     removeMotionCallback(&gemmouse::mouseMotionCallback, this);
     removeButtonCallback(&gemmouse::mouseButtonCallback, this);
+    removeWheelCallback(&gemmouse::mouseWheelCallback, this);
 
     outlet_free(m_outXPos);
     outlet_free(m_outYPos);
@@ -63,8 +83,11 @@ gemmouse :: ~gemmouse()
 /////////////////////////////////////////////////////////
 void gemmouse :: mouseMotion(int x, int y)
 {
-    outlet_float(m_outYPos, (t_float)y);
-    outlet_float(m_outXPos, (t_float)x);
+  t_float scalex = (m_scaleX==0.f)?1:m_scaleX/GemMan::m_w;
+  t_float scaley = (m_doY)?((m_scaleY==0.f)?1:m_scaleY/GemMan::m_h):scalex;
+
+  outlet_float(m_outYPos, (t_float)(y*scaley));
+  outlet_float(m_outXPos, (t_float)(x*scalex));
 }
 
 /////////////////////////////////////////////////////////
@@ -73,12 +96,19 @@ void gemmouse :: mouseMotion(int x, int y)
 /////////////////////////////////////////////////////////
 void gemmouse :: mouseButton(int which, int state, int x, int y)
 {
-    if (which == 0)
-        outlet_float(m_outLBut, (t_float)state);
-    else if (which == 1)
-        outlet_float(m_outMBut, (t_float)state);
-    else if (which == 2)
-        outlet_float(m_outRBut, (t_float)state);
+  switch (which){
+  case 0: outlet_float(m_outLBut, (t_float)state); break;
+  case 1: outlet_float(m_outMBut, (t_float)state); break;
+  case 2: outlet_float(m_outRBut, (t_float)state); break;
+  }
+}
+
+/////////////////////////////////////////////////////////
+// mouseButton
+//
+/////////////////////////////////////////////////////////
+void gemmouse :: mouseWheel(int axis, int value)
+{
 }
 
 /////////////////////////////////////////////////////////
@@ -95,3 +125,7 @@ void gemmouse :: mouseButtonCallback(int which, int state, int x, int y, void *d
 {
     ((gemmouse *)data)->mouseButton(which, state, x, y);
 }
+void gemmouse :: mouseWheelCallback(int axis, int value, void *data)
+{
+    ((gemmouse *)data)->mouseWheel(axis, value);
+}
