@@ -5,6 +5,8 @@ LOG
     Respond to mouse events
     
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -13,6 +15,10 @@ LOG
 #ifndef INCLUDE_GEMMOUSE_H_
 #define INCLUDE_GEMMOUSE_H_
 
+#ifndef HELPSYMBOL_BASE
+# define HELPSYMBOL_BASE "Gem/"
+#endif
+
 #include "Base/CPPExtern.h"
 
 /*-----------------------------------------------------------------
@@ -34,7 +40,7 @@ class GEM_EXTERN gemmouse : public CPPExtern
 
         //////////
         // Constructor
-        gemmouse();
+  gemmouse(int,t_atom*);
     	
     protected:
     	
@@ -50,6 +56,10 @@ class GEM_EXTERN gemmouse : public CPPExtern
         // mouse button
         void            mouseButton(int which, int state, int x, int y);
 
+        //////////
+        // mouse button
+        void		mouseWheel(int axis, int value);
+        
         //////////
         // The xpos outlet
         t_outlet    	*m_outXPos;
@@ -70,12 +80,23 @@ class GEM_EXTERN gemmouse : public CPPExtern
         // The right outlet
         t_outlet    	*m_outRBut;
 
+	//////////
+	// coordinate-scales
+	// if !=0, the mouse-coordinate is scaled to 0..m_scale
+	// if ==0, the mouse-coordinate is scaled to 0..windowsize
+	t_float m_scaleX, m_scaleY;
+
+	//////////
+	// should Y we scaled separately or like X ?
+	bool m_doY;
+
     private:
 
         //////////
         // Static member functions
         static void     mouseMotionCallback(int x, int y, void *data);
         static void     mouseButtonCallback(int which, int state, int x, int y, void *data);
+        static void	mouseWheelCallback(int axis, int value, void *data);
 };
 
-#endif  // for header file
\ No newline at end of file
+#endif  // for header file
