@@ -5,6 +5,8 @@ LOG
     Respond to space orb events
     
     Copyright (c) 1997-1998 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -13,6 +15,10 @@ LOG
 #ifndef INCLUDE_GEMORB_H_
 #define INCLUDE_GEMORB_H_
 
+#ifndef HELPSYMBOL_BASE
+# define HELPSYMBOL_BASE "Gem/"
+#endif
+
 #include "Base/CPPExtern.h"
 
 typedef void * OrbHandle;
