@@ -5,6 +5,8 @@ LOG
     Respond to tablet events
     
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -13,6 +15,10 @@ LOG
 #ifndef INCLUDE_GEMTABLET_H_
 #define INCLUDE_GEMTABLET_H_
 
+#ifndef HELPSYMBOL_BASE
+# define HELPSYMBOL_BASE "Gem/"
+#endif
+
 #include "Base/CPPExtern.h"
 
 /*-----------------------------------------------------------------
@@ -99,4 +105,4 @@ class GEM_EXTERN gemtablet : public CPPExtern
         static void     tabletButtonCallback(int which, int state, int x, int y, void *data);
 };
 
-#endif  // for header file
\ No newline at end of file
+#endif  // for header file
