@@ -5,6 +5,8 @@ LOG
     A curve
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -48,10 +50,6 @@ class GEM_EXTERN curve : public polygon
     	// Do the rendering
     	virtual void 	render(GemState *state);
 
-    	//////////
-    	// How the object should be drawn
-    	virtual void	typeMess(t_symbol *type);
-
     	//////////
     	// Resolution callback
     	void	    	resolutionMess(int res);
@@ -60,11 +58,13 @@ class GEM_EXTERN curve : public polygon
     	// The rendering resolution
     	int 	    	m_resolution;
 
+	GLfloat m_texCoords[4][2];
+
     private:
     	
     	//////////
     	// Static member functions
-    	static void 	resolutionMessCallback(void *data, t_floatarg res);
+     	static void 	resolutionMessCallback(void *data, t_floatarg res);
 };
 
 #endif	// for header file
