@@ -4,7 +4,9 @@ LOG
 
     A polygon
 
-    Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) 1997-2000 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -14,6 +16,8 @@ LOG
 #define INCLUDE_POLYGON_H_
 
 #include "Base/GemBase.h"
+#include "Base/GemShape.h"
+
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
@@ -37,9 +41,9 @@ DESCRIPTION
     "vert_9" - The tenth vertex
      
 -----------------------------------------------------------------*/
-class GEM_EXTERN polygon : public GemBase
+class GEM_EXTERN polygon : public GemShape
 {
-    CPPEXTERN_HEADER(polygon, GemBase)
+    CPPEXTERN_HEADER(polygon, GemShape)
 
     public:
 
@@ -73,17 +77,14 @@ class GEM_EXTERN polygon : public GemBase
 	    // GROUP:	Member variables
 	    //-----------------------------------
     
-    	//////////
-    	// The line width for GL_LINE mode
-		GLfloat	    	m_linewidth;
-
     	//////////
     	// The number of inputs (the number of points)
     	int 	    	m_numInputs;
     	
     	//////////
     	// The vertices
-    	float	    	m_vert[10][3];
+	float  *m_vertarray;
+    	float **m_vert;
 
         //////////
         // The drawing style (GL_LINE, GL_POLYGON, etc)
@@ -95,16 +96,7 @@ class GEM_EXTERN polygon : public GemBase
     	// Static member functions
     	static void 	linewidthMessCallback(void *data, t_floatarg linewidth);
     	static void 	typeMessCallback(void *data, t_symbol *type);
-    	static void 	setVert0Callback(void *data, t_floatarg x, t_floatarg y, t_floatarg z);
-    	static void 	setVert1Callback(void *data, t_floatarg x, t_floatarg y, t_floatarg z);
-    	static void 	setVert2Callback(void *data, t_floatarg x, t_floatarg y, t_floatarg z);
-    	static void 	setVert3Callback(void *data, t_floatarg x, t_floatarg y, t_floatarg z);
-    	static void 	setVert4Callback(void *data, t_floatarg x, t_floatarg y, t_floatarg z);
-    	static void 	setVert5Callback(void *data, t_floatarg x, t_floatarg y, t_floatarg z);
-    	static void 	setVert6Callback(void *data, t_floatarg x, t_floatarg y, t_floatarg z);
-    	static void 	setVert7Callback(void *data, t_floatarg x, t_floatarg y, t_floatarg z);
-    	static void 	setVert8Callback(void *data, t_floatarg x, t_floatarg y, t_floatarg z);
-    	static void 	setVert9Callback(void *data, t_floatarg x, t_floatarg y, t_floatarg z);
+    	static void 	vertCallback(void *data, t_symbol *type, int argc, t_atom*argv);
 };
 
 #endif	// for header file
