@@ -5,6 +5,8 @@ LOG
     A text2d
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -15,8 +17,12 @@ LOG
 
 #include "Base/TextBase.h"
 
-class GLTTBitmapFont;
-class FTFace;
+#ifdef GLTT
+#include "GLTTBitmapFont.h"
+//# if defined __linux__ || defined __APPLE__
+# include "GLTTPixmapFont.h"
+//# endif
+#endif
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
@@ -44,38 +50,32 @@ class GEM_EXTERN text2d : public TextBase
     	// Destructor
     	virtual ~text2d();
 
-    	//////////
+   	//////////
     	// Do the rendering
     	virtual void 	render(GemState *state);
 
-    	//////////
-    	// The font to use
-    	virtual void   	fontNameMess(const char *filename);
+	//////
+	// anti aliasing (aka: pixmap instead of bitmap)
+	int m_antialias;
+	void            aliasMess(int aa);
 
-		//////////
-		// Create the actual font from the face
-		int				makeFontFromFace();
+#ifdef FTGL
+	void            setFontSize(t_float size);
 
-		//////////
-		// Set the font size
-		virtual void	setFontSize(int size);
-
-		//////////
-		// Set the precision for rendering
-		// This is a no-op
-		virtual void	setPrecision(float)			{ }
-
-	    //-----------------------------------
-	    // GROUP:	Member variables
-	    //-----------------------------------
-    
-	   	//////////
+	virtual FTFont*	makeFont(const char*fontname);
+	FTFont                  *m_afont;
+#elif defined GLTT
+	virtual void    destroyFont();
+	virtual int     makeFontFromFace();
+	//////////
     	// The font structure
-    	GLTTBitmapFont	*m_font;
+    	GLTTBitmapFont		*m_font;
+    	GLTTPixmapFont		*m_afont;
+#endif
+
+ private:
+	static void     aliasMessCallback(void *data, t_floatarg aa);
 
-    	//////////
-    	// The font structure
-    	FTFace 			*m_face;
 };
 
 #endif	// for header file
