@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2003 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -14,8 +16,9 @@
 
 #include "textoutline.h"
 
-#include "FTFace.h"
-#include "GLTTOutlineFont.h"
+#ifdef FTGL
+#include "FTGLOutlineFont.h"
+#endif
 
 CPPEXTERN_NEW_WITH_GIMME(textoutline)
 
@@ -27,12 +30,35 @@ CPPEXTERN_NEW_WITH_GIMME(textoutline)
 // Constructor
 //
 /////////////////////////////////////////////////////////
+#ifdef FTGL
 textoutline :: textoutline(int argc, t_atom *argv)
-			 : TextBase(argc, argv), m_font(NULL), m_face(NULL)
-{
-	m_fontSize = 20;
-	fontNameMess(DEFAULT_FONT);
+  : TextBase(argc, argv) {
+  fontNameMess(DEFAULT_FONT);
+} 
+textoutline :: ~textoutline() {
+  if(m_font)delete m_font;m_font=NULL;
 }
+FTFont *textoutline :: makeFont(const char*fontfile){
+  if(m_font)delete m_font; m_font=NULL;
+  m_font =  new FTGLOutlineFont(fontfile);
+  if (m_font->Error()){
+    delete m_font;
+    m_font = NULL;
+  }
+  return m_font;
+}
+
+#elif defined GLTT
+
+textoutline :: textoutline(int argc, t_atom *argv)
+  : TextBase(argc, argv)
+    , m_font(NULL)
+{
+#ifdef MACOSX
+  if (!HaveValidContext ()) {post("GEM: geo: textoutline - need window to load font");return;}
+#endif
+   fontNameMess(DEFAULT_FONT);
+ }
 
 /////////////////////////////////////////////////////////
 // Destructor
@@ -40,76 +66,32 @@ textoutline :: textoutline(int argc, t_atom *argv)
 /////////////////////////////////////////////////////////
 textoutline :: ~textoutline()
 {
-    delete m_font;
-	delete m_face;
-}
-
-/////////////////////////////////////////////////////////
-// setPrecision
-//
-/////////////////////////////////////////////////////////
-void textoutline :: setPrecision(float prec)
-{
-	m_precision = prec;
-	m_valid = makeFontFromFace();
-	setModified();
-}
-
-/////////////////////////////////////////////////////////
-// setFontSize
-//
-/////////////////////////////////////////////////////////
-void textoutline :: setFontSize(int size)
-{
-	m_fontSize = size;
-	m_valid = makeFontFromFace();
-	setModified();
-}
-
-/////////////////////////////////////////////////////////
-// fontNameMess
-//
-/////////////////////////////////////////////////////////
-void textoutline :: fontNameMess(const char *filename)
-{
-	m_valid = 0;
-	delete m_font;
-	m_font = NULL;
-	delete m_face;
-	m_face = new FTFace;
-    char buf[MAXPDSTRING];
-    canvas_makefilename(getCanvas(), (char *)filename, buf, MAXPDSTRING);
-
-	if( ! m_face->open(buf) )
-	{
-		error("GEM: textoutline: unable to open font: %s", buf);
-		return;
-	}
-	m_valid = makeFontFromFace();
-    setModified();
+  if(m_font)delete m_font;m_font=NULL;
+  if(m_face)delete m_face;m_face=NULL;
 }
 
 /////////////////////////////////////////////////////////
 // makeFontFromFace
 //
 /////////////////////////////////////////////////////////
+void textoutline :: destroyFont() {
+  if(m_font)delete m_font; m_font=NULL;
+}
 int textoutline :: makeFontFromFace()
 {
-	if (!m_face)
-	{
-		error("GEM: text2d: True type font doesn't exist");
-		return(0);
-	}
-
-	delete m_font;
-	m_font = new GLTTOutlineFont(m_face);
-	m_font->setPrecision((double)m_precision);
-	if( ! m_font->create(m_fontSize) )
-	{
-		error("GEM: textoutline: unable to create vectored font");
-		return(0);
-	}
-	return(1);
+  if(m_font)delete m_font;m_font=NULL;
+  if (!m_face)    {
+    error("GEM: textoutline: True type font doesn't exist");
+    return(0);
+  }
+  m_font = new GLTTOutlineFont(m_face);
+  m_font->setPrecision((double)m_precision);
+  if( ! m_font->create((int)m_fontSize) ) {
+    error("GEM: textoutline: unable to create outlined font");
+    delete m_font; m_font = NULL;
+    return(0);
+  }
+  return(1);
 }
 
 /////////////////////////////////////////////////////////
@@ -118,35 +100,36 @@ int textoutline :: makeFontFromFace()
 /////////////////////////////////////////////////////////
 void textoutline :: render(GemState *)
 {
-	if (m_valid)
-	{
-	    glPushMatrix();
+  if (m_valid && m_theString) {
+    // compute the offset due to the justification
+    float x=0, y=0;
 
-		// compute the offset due to the justification
-		float width = 0.f;
-		if (m_widthJus == LEFT)
-			width = 0.f;
-		else if (m_widthJus == RIGHT)
-			width = (float)(m_font->getWidth(m_theString));
-		else if (m_widthJus == CENTER)
-			width = (float)(m_font->getWidth(m_theString) / 2.f);
-
-		float height = 0.f;
-		if (m_heightJus == BOTTOM)
-			height = 0.f;
-		else if (m_heightJus == TOP)
-			height = (float)(m_font->getHeight());
-		else if (m_heightJus == MIDDLE)
-			height = (float)(m_font->getHeight() / 2.f);
-
-		glScalef(.05f, .05f, .05f);
-		glTranslatef(-width, -height, 0.f);
-		m_font->output(m_theString);
-
-		glPopMatrix();
-	}
+    x=m_font->getWidth (m_theString);
+    y=m_font->getHeight();
+    glPushMatrix();
+    justifyFont(0, 0, 0, x, y, 0);
+    m_font->output(m_theString);
+    
+    glPopMatrix();
+  }
 }
 
+
+#else /* !FTGL && !GLTT */
+
+textoutline :: textoutline(int argc, t_atom *argv)
+  : TextBase(argc, argv)
+{ }
+
+/////////////////////////////////////////////////////////
+// Destructor
+//
+/////////////////////////////////////////////////////////
+textoutline :: ~textoutline()
+{}
+
+#endif /* !GLTT && !FTGL */
+
 /////////////////////////////////////////////////////////
 // static member function
 //
