@@ -5,6 +5,8 @@ LOG
     A world_light
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -13,9 +15,18 @@ LOG
 #ifndef INCLUDE_WORLD_LIGHT_H_
 #define INCLUDE_WORLD_LIGHT_H_
 
-#include "Base/GemBase.h"
+// I hate Microsoft...I shouldn't have to do this!
+#ifdef _WINDOWS
+#include <windows.h>
+#endif
 
+#ifdef __APPLE__
+#include <OpenGL/glu.h>
+#else
 #include <GL/glu.h>
+#endif // __APPLE__
+
+#include "Base/GemBase.h"
 
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
