@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -16,7 +18,7 @@
 
 #include "Base/GemCache.h"
 
-CPPEXTERN_NEW(pix_buf)
+CPPEXTERN_NEW_WITH_ONE_ARG(pix_buf, t_floatarg, A_DEFFLOAT)
 
 /////////////////////////////////////////////////////////
 //
@@ -26,10 +28,9 @@ CPPEXTERN_NEW(pix_buf)
 // Constructor
 //
 /////////////////////////////////////////////////////////
-pix_buf :: pix_buf()
-    	 : m_oldcache(NULL)
+pix_buf :: pix_buf(t_floatarg a=0) :
+  orgPixBlock(NULL),m_banged(false), m_auto(a!=0.0)
 {
-    m_pixBlock.image.data = NULL;
 }
 
 /////////////////////////////////////////////////////////
@@ -37,10 +38,7 @@ pix_buf :: pix_buf()
 //
 /////////////////////////////////////////////////////////
 pix_buf :: ~pix_buf()
-{
-    if (m_oldcache) stopRendering();
-    cleanImage();
-}
+{}
 
 /////////////////////////////////////////////////////////
 // render
@@ -48,21 +46,16 @@ pix_buf :: ~pix_buf()
 /////////////////////////////////////////////////////////
 void pix_buf :: render(GemState *state)
 {
-    // the cache and image should have been set
-    if (!m_oldcache || !state->image ) return;
-    
-    // if it is a new image or a dirty image, reprocess
-    if ( state->image->newimage || m_cache->resendImage )
-    {
-    	if (!m_pixBlock.image.data)
-    	    copy2Image(&(m_pixBlock.image), &(state->image->image));
-    	else
-    	    refreshImage(&(m_pixBlock.image), &(state->image->image));
-    	m_pixBlock.newimage = 1;
-    	m_cache->resendImage = 0;
-    }
-
-    state->image = &m_pixBlock;
+  m_banged|=m_auto;
+  cachedPixBlock.newimage = 0;
+  if (!state || !state->image || !&state->image->image) return;
+  if (state->image->newimage || m_banged){
+    orgPixBlock = state->image;
+    state->image->image.copy2Image(&cachedPixBlock.image);
+    cachedPixBlock.newimage = 1;
+  }
+  state->image = &cachedPixBlock;
+  m_banged = false;
 }
 
 /////////////////////////////////////////////////////////
@@ -71,8 +64,7 @@ void pix_buf :: render(GemState *state)
 /////////////////////////////////////////////////////////
 void pix_buf :: postrender(GemState *state)
 {
-    m_pixBlock.newimage = 0;
-    state->image = NULL;
+  state->image = orgPixBlock;
 }
 
 /////////////////////////////////////////////////////////
@@ -81,9 +73,7 @@ void pix_buf :: postrender(GemState *state)
 /////////////////////////////////////////////////////////
 void pix_buf :: startRendering()
 {
-    m_oldcache = m_cache;
-    m_cache = new GemCache(m_oldcache->m_parent);
-    cleanImage();
+  //  m_banged = true;
 }
 
 /////////////////////////////////////////////////////////
@@ -92,8 +82,6 @@ void pix_buf :: startRendering()
 /////////////////////////////////////////////////////////
 void pix_buf :: stopRendering()
 {
-    if (m_cache) delete m_cache;
-    cleanImage();
 }
 
 /////////////////////////////////////////////////////////
@@ -102,16 +90,42 @@ void pix_buf :: stopRendering()
 /////////////////////////////////////////////////////////
 void pix_buf :: cleanImage()
 {
-    if (m_pixBlock.image.data)
-    {
-    	delete [] m_pixBlock.image.data;
-    	m_pixBlock.image.data = NULL;
-    }
 }
 
+
+/////////////////////////////////////////////////////////
+// bangMess
+//
+/////////////////////////////////////////////////////////
+void pix_buf :: bangMess()
+{
+  m_banged = true;
+}
+/////////////////////////////////////////////////////////
+// autoMess
+//
+/////////////////////////////////////////////////////////
+void pix_buf :: autoMess(int a)
+{
+  m_auto = (a!=0);
+}
 /////////////////////////////////////////////////////////
 // static member function
 //
 /////////////////////////////////////////////////////////
-void pix_buf :: obj_setupCallback(t_class *)
-{ }
+void pix_buf :: obj_setupCallback(t_class *classPtr)
+{ 
+  class_addcreator((t_newmethod)_classpix_buf, 
+		   gensym("pix_separator"), A_DEFFLOAT, A_NULL);
+  class_addbang(classPtr, &pix_buf::bangMessCallback);
+  class_addmethod(classPtr, (t_method)&pix_buf::autoMessCallback,
+		  gensym("auto"), A_FLOAT, A_NULL);
+
+}
+
+void pix_buf :: bangMessCallback(void *data){
+  GetMyClass(data)->bangMess();
+}
+void pix_buf :: autoMessCallback(void *data, t_floatarg f){
+  GetMyClass(data)->autoMess((int)f);
+}
