@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -45,9 +47,13 @@ pix_clearblock :: ~pix_clearblock()
 /////////////////////////////////////////////////////////
 void pix_clearblock :: render(GemState *state)
 {
-    // the cache and image should have been set
-    if (!m_oldcache) return;
-    state->image = NULL;
+  // the cache and image should have been set
+  if (!m_oldcache || m_oldcache->m_magic!=GEMCACHE_MAGIC){
+    // our cache has not been set or has been destroyed
+    startRendering(); // i'm not sure, whether this breaks the default behaviour
+    return;
+  }
+  state->image = NULL;
 }
 
 /////////////////////////////////////////////////////////
@@ -65,7 +71,12 @@ void pix_clearblock :: postrender(GemState *state)
 /////////////////////////////////////////////////////////
 void pix_clearblock :: startRendering()
 {
-    m_oldcache = m_cache;
+  if (m_cache && m_cache->m_magic!=GEMCACHE_MAGIC)
+    m_cache=NULL;
+
+  m_oldcache = m_cache;
+
+  if(m_oldcache)
     m_cache = new GemCache(m_oldcache->m_parent);
 }
 
