@@ -2,9 +2,11 @@
 LOG
     GEM - Graphics Environment for Multimedia
 
-    A pix_coordinate
+    set the texture coordinates of a pixBlock
 
     Copyright (c) 1997-1998 Mark Danks
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
