@@ -2,11 +2,13 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1999 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -42,7 +44,7 @@ pix_draw :: ~pix_draw()
 /////////////////////////////////////////////////////////
 void pix_draw :: render(GemState *state)
 {
-    if ( !state->image ) return;
+    if ( !state->image || !&state->image->image ) return;
 
     glRasterPos2i(0, 0);
     // hack to center image at 0,0
