@@ -5,6 +5,9 @@ LOG
     Pixel color inversion
 
     Copyright (c) 1997-1998 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -46,11 +49,10 @@ class GEM_EXTERN pix_invert : public GemPixObj
 
     	//////////
     	// Do the processing
-    	virtual void 	processImage(imageStruct &image);
-
-    	//////////
-    	// This is called whenever a new gray8 image comes through.
+    	virtual void 	processRGBAImage(imageStruct &image);
     	virtual void 	processGrayImage(imageStruct &image);
+        virtual void 	processYUVImage(imageStruct &image);
+        virtual void 	processYUVAltivec(imageStruct &image);
 };
 
 #endif	// for header file
