@@ -2,11 +2,14 @@
 //
 // GEM - Graphics Environment for Multimedia
 //
-// mark@danks.org
+// zmoelnig@iem.kug.ac.at
 //
 // Implementation file
 //
 //    Copyright (c) 1997-1998 Mark Danks.
+//    Copyright (c) Gnther Geiger.
+//    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM
+//    Copyright (c) 2002 James Tittle & Chris Clepper
 //    For information on usage and redistribution, and for a DISCLAIMER OF ALL
 //    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 //
@@ -38,39 +41,36 @@ pix_mask :: ~pix_mask()
 // processDualImage
 //
 /////////////////////////////////////////////////////////
-void pix_mask :: processDualImage(imageStruct &image, imageStruct &right)
+void pix_mask :: processRGBA_RGBA(imageStruct &image, imageStruct &right)
 {
-    int datasize = image.xsize * image.ysize;
-	unsigned char *pixels = image.data;
-	unsigned char *mask = right.data;
+  int datasize = image.xsize * image.ysize;
+  unsigned char *pixels = image.data;
+  unsigned char *mask = right.data;
 
-	while (datasize--)
-	{
-    	// do we use the alpha value
-    	pixels[chAlpha] = (	(int)mask[chRed] +
-					    	(int)mask[chGreen] +
-    						(int)mask[chBlue] ) / 3;
-		pixels += 4;
-		mask += 4;
-	}
+  while (datasize--)	{
+    // do we use the alpha value
+    pixels[chAlpha] = (	(int)mask[chRed] +
+			(int)mask[chGreen] +
+			(int)mask[chBlue] ) / 3;
+    pixels += 4;
+    mask += 4;
+  }
 }
 
 /////////////////////////////////////////////////////////
 // processRightGray
 //
 /////////////////////////////////////////////////////////
-void pix_mask :: processRightGray(imageStruct &image, imageStruct &right)
+void pix_mask :: processRGBA_Gray(imageStruct &image, imageStruct &right)
 {
-    int datasize = image.xsize * image.ysize;
-	unsigned char *pixels = image.data;
-	unsigned char *mask = right.data;
+  int datasize = image.xsize * image.ysize;
+  unsigned char *pixels = image.data;
+  unsigned char *mask = right.data;
 
-	while(datasize--)
-	{
-   		pixels[chAlpha] = *mask;
-		pixels += 4;
-		mask++;
-	}
+  while(datasize--)	{
+    pixels[chAlpha] = *mask++;
+    pixels += 4;
+  }
 }
 
 /////////////////////////////////////////////////////////
