@@ -5,6 +5,8 @@ LOG
     Load multiple images into a pix block
 
     Copyright (c) 1997-1999 Mark Danks
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -50,13 +52,12 @@ class GEM_EXTERN pix_multiimage : public GemBase
                 
                 multiImageCache(const char *_imageName)
                         : refCount(0), next(NULL), images(NULL), textBind(NULL),
-							numImages(0), baseImage(0), topImage(0),
-							skipRate(0)
+                            numImages(0), baseImage(0), topImage(0), skipRate(0)
                         { imageName = strdup(_imageName); }
                 ~multiImageCache()
                             { delete imageName;
                               for(int i=0; i < numImages;i++)
-                              { delete [] images[i]->data;
+                              {
                         	    delete images[i];
                               }
 							  delete [] textBind;
@@ -65,8 +66,8 @@ class GEM_EXTERN pix_multiimage : public GemBase
                 int                 refCount;
                 multiImageCache     *next;
                 imageStruct         **images;
+                unsigned int		*textBind;
                 int                 numImages;
-				unsigned int		*textBind;
                 char                *imageName;
                 int                 baseImage;
                 int                 topImage;
@@ -120,6 +121,7 @@ class GEM_EXTERN pix_multiimage : public GemBase
     	//////////
     	// The pixBlock with the current image
     	pixBlock    	m_pixBlock;
+	imageStruct     m_imageStruct;
 
     	//////////
     	// The original images
