@@ -4,7 +4,10 @@ LOG
 
     Subtract two images.
 
-    Copyright (c) 1997-1998 Mark Danks
+    Copyright (c) 1997-1998 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) 2002 James Tittle & Chris Clepper
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -46,7 +49,13 @@ class GEM_EXTERN pix_subtract : public GemPixDualObj
 
     	//////////
     	// Do the processing
-    	virtual void 	processDualImage(imageStruct &image, imageStruct &right);
+    	virtual void 	processRGBA_RGBA(imageStruct &image, imageStruct &right);
+	//    	virtual void 	processGray_Gray(imageStruct &image, imageStruct &right);
+    	virtual void 	processRGBA_Gray(imageStruct &image, imageStruct &right);
+    	virtual void 	processYUV_YUV(imageStruct &image, imageStruct &right);
+        virtual void	processYUVAltivec(imageStruct &image, imageStruct &right);
+        virtual void	processRGB_Altivec(imageStruct &image, imageStruct &right);
+	virtual void    processDualImage(imageStruct &image, imageStruct &right);
 };
 
 #endif	// for header file
